Versions
========

0.1.4 (2020-02-19)
========
- Package 0.1.4 version
- Specify runner command in readme file
- Introduce short runner flag '--eo'

0.1.3 (2020-02-14)
========
- Create installable package via pip

0.1.2 (2020-02-14)
========
- Create plugin unittests

0.1.1 (2020-02-13)
========
- Introduce PYPI package

0.1.0 (2020-02-12)
========
- Distribute initial package version
